##############################################################################
##### How to apply SECR models using the package "secr" implemented in R #####
##### Examples from Bylot Island: trapping data from 2016                #####
##### Two trapping grids: first = wet tudnra / second = mesic tundra     #####
##### In this file, you can find codes listed in the main text           #####
##############################################################################

library(secr)
library(parallel)
trap.wet<-read.capthist(captfile="C:/ULaval/Post-doc/Manuel_Estimations/LemmusBylot_Wet2016_Captures.txt", trapfile="C:/ULaval/Post-doc/Manuel_Estimations/LemmusBylot_Wet2016_Traps.txt", covnames=c("species","sex","age","mass","repro"), detector="single", fmt="trapID")

# Model 1: Density~session; detection probability~session; movements~session
secr.wet.1<-secr.fit(trap.wet, model=list(D~session,g0~session,sigma~session), buffer=100, detectfn=0, trace=TRUE, ncores=3)
# Model 2: Density~session; detection probability~session+previous capture; 
# movements~session
secr.wet.2<-secr.fit(trap.wet, model=list(D~session, g0~session+b, sigma~session), buffer=100, detectfn=0, trace=TRUE , ncores=3)

# Model 3: Density~session; detection probability~session+previous capture; 
# movements~session+previous capture
secr.wet.3<-secr.fit(trap.wet, model=list(D~session, g0~session+b, sigma~session+b), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 4: Density~session; detection probability~session; movements~constant
secr.wet.4<-secr.fit(trap.wet, model=list(D~session,g0~session,sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 5: Density~session; detection probability~session+previous capture; 
# movements~constant
secr.wet.5<-secr.fit(trap.wet, model=list(D~session,g0~session+b,sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 6: Density~session; detection probability~constant; movements~constant
secr.wet.6<-secr.fit(trap.wet, model=list(D~session,g0~1,sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

AIC(secr.wet.1,secr.wet.4,secr.wet.5,secr.wet.6)
model.average(secr.wet.1, secr.wet.4, secr.wet.5, secr.wet.6, betanames = "D")



### Models for trapping grid 2 located in the mesic habitat. Load file first.

trap.mesic<-read.capthist("C:/ULaval/Post-doc/Manuel_Estimations/LemmusBylot_Mesic2016_Captures.txt", "C:/ULaval/Post-doc/Manuel_Estimations/LemmusBylot_Mesic2016_Traps.txt", covnames=c("species","sex","age","mass","repro"), detector="single", fmt="trapID")

# Model 1: Density~session; detection probability~session; movements~session
secr.mesic.1<-secr.fit(trap.mesic, model=list(D~session, g0~session, sigma~session), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 2: Density~session; detection probability~session+previous capture; 
# movements~session
secr.mesic.2<-secr.fit(trap.mesic, model=list(D~session, g0~session+b, sigma~session), buffer=100, detectfn=0, trace=TRUE , ncores=3)

# Model 3: Density~session; detection probability~session+previous capture; 
# movements~session+previous capture
secr.mesic.3<-secr.fit(trap.mesic, model=list(D~session, g0~session+b, sigma~session+b), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 4: Density~session; detection probability~session; movements~constant
secr.mesic.4<-secr.fit(trap.mesic, model=list(D~session, g0~session, sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 5: Density~session; detection probability~session+previous capture; 
# movements~constant
secr.mesic.5<-secr.fit(trap.mesic, model=list(D~session, g0~session+b, sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

# Model 6: Density~session; detection probability~constant; movements~constant
secr.mesic.6<-secr.fit(trap.mesic, model=list(D~session, g0~1, sigma~1), buffer=100, detectfn=0, trace=TRUE, ncores=3)

AIC(secr.mesic.1, secr.mesic.2, secr.mesic.3, secr.mesic.4, secr.mesic.5, secr.mesic.6)
model.average(secr.mesic.2, secr.mesic.3, secr.mesic.5, realnames = "D")










